export type CollectionType<T> = {
  data: T[];
  has_more: boolean;
  from: number;
  to: number;
  per_page: number;
  current_page: number;
  total: number;
};
export type CollectionMethods<T> = {
  fromResponse: (response: CollectionType<T>) => void;
  empty: () => boolean;
};

export default function useCollection<T>() {
  const collection = reactive<CollectionType<T> & CollectionMethods<T>>({
    data: [],
    has_more: false,
    from: 0,
    to: 0,
    per_page: 0,
    current_page: 0,
    total: 0,
    fromResponse(response: CollectionType<T>) {
      this.data = response.data;
      this.has_more = response.has_more;
      this.from = response.from;
      this.to = response.to;
      this.per_page = response.per_page;
      this.current_page = response.current_page;
      this.total = response.total;
    },
    empty() {
      return this.data.length === 0;
    },
  });

  return collection;
}
